@@ -16,14 +16,15 @@ from scipy import sparse
 from numpy.lib.stride_tricks import as_strided
 
 from ..utils import check_array, check_random_state
-from ..utils.validation import _deprecate_positional_args
 from ..base import BaseEstimator
 
-__all__ = ['PatchExtractor',
-           'extract_patches_2d',
-           'grid_to_graph',
-           'img_to_graph',
-           'reconstruct_from_patches_2d']
+__all__ = [
+    "PatchExtractor",
+    "extract_patches_2d",
+    "grid_to_graph",
+    "img_to_graph",
+    "reconstruct_from_patches_2d",
+]
 
 ###############################################################################
 # From an image to a graph
@@ -42,10 +43,8 @@ def _make_edges_3d(n_x, n_y, n_z=1):
         The size of the grid in the z direction, defaults to 1
     """
     vertices = np.arange(n_x * n_y * n_z).reshape((n_x, n_y, n_z))
-    edges_deep = np.vstack((vertices[:, :, :-1].ravel(),
-                            vertices[:, :, 1:].ravel()))
-    edges_right = np.vstack((vertices[:, :-1].ravel(),
-                             vertices[:, 1:].ravel()))
+    edges_deep = np.vstack((vertices[:, :, :-1].ravel(), vertices[:, :, 1:].ravel()))
+    edges_right = np.vstack((vertices[:, :-1].ravel(), vertices[:, 1:].ravel()))
     edges_down = np.vstack((vertices[:-1].ravel(), vertices[1:].ravel()))
     edges = np.hstack((edges_deep, edges_right, edges_down))
     return edges
@@ -53,23 +52,29 @@ def _make_edges_3d(n_x, n_y, n_z=1):
 
 def _compute_gradient_3d(edges, img):
     _, n_y, n_z = img.shape
-    gradient = np.abs(img[edges[0] // (n_y * n_z),
-                      (edges[0] % (n_y * n_z)) // n_z,
-                      (edges[0] % (n_y * n_z)) % n_z] -
-                      img[edges[1] // (n_y * n_z),
-                      (edges[1] % (n_y * n_z)) // n_z,
-                      (edges[1] % (n_y * n_z)) % n_z])
+    gradient = np.abs(
+        img[
+            edges[0] // (n_y * n_z),
+            (edges[0] % (n_y * n_z)) // n_z,
+            (edges[0] % (n_y * n_z)) % n_z,
+        ]
+        - img[
+            edges[1] // (n_y * n_z),
+            (edges[1] % (n_y * n_z)) // n_z,
+            (edges[1] % (n_y * n_z)) % n_z,
+        ]
+    )
     return gradient
 
 
 # XXX: Why mask the image after computing the weights?
 
+
 def _mask_edges_weights(mask, edges, weights=None):
     """Apply a mask to edges (weighted or not)"""
     inds = np.arange(mask.size)
     inds = inds[mask.ravel()]
-    ind_mask = np.logical_and(np.in1d(edges[0], inds),
-                              np.in1d(edges[1], inds))
+    ind_mask = np.logical_and(np.in1d(edges[0], inds), np.in1d(edges[1], inds))
     edges = edges[:, ind_mask]
     if weights is not None:
         weights = weights[ind_mask]
@@ -77,7 +82,7 @@ def _mask_edges_weights(mask, edges, weights=None):
         maxval = edges.max()
     else:
         maxval = 0
-    order = np.searchsorted(np.unique(edges.ravel()), np.arange(maxval + 1))
+    order = np.searchsorted(np.flatnonzero(mask), np.arange(maxval + 1))
     edges = order[edges]
     if weights is None:
         return edges
@@ -85,10 +90,10 @@ def _mask_edges_weights(mask, edges, weights=None):
         return edges, weights
 
 
-def _to_graph(n_x, n_y, n_z, mask=None, img=None,
-              return_as=sparse.coo_matrix, dtype=None):
-    """Auxiliary function for img_to_graph and grid_to_graph
-    """
+def _to_graph(
+    n_x, n_y, n_z, mask=None, img=None, return_as=sparse.coo_matrix, dtype=None
+):
+    """Auxiliary function for img_to_graph and grid_to_graph"""
     edges = _make_edges_3d(n_x, n_y, n_z)
 
     if dtype is None:
@@ -120,19 +125,21 @@ def _to_graph(n_x, n_y, n_z, mask=None, img=None,
     diag_idx = np.arange(n_voxels)
     i_idx = np.hstack((edges[0], edges[1]))
     j_idx = np.hstack((edges[1], edges[0]))
-    graph = sparse.coo_matrix((np.hstack((weights, weights, diag)),
-                              (np.hstack((i_idx, diag_idx)),
-                               np.hstack((j_idx, diag_idx)))),
-                              (n_voxels, n_voxels),
-                              dtype=dtype)
+    graph = sparse.coo_matrix(
+        (
+            np.hstack((weights, weights, diag)),
+            (np.hstack((i_idx, diag_idx)), np.hstack((j_idx, diag_idx))),
+        ),
+        (n_voxels, n_voxels),
+        dtype=dtype,
+    )
     if return_as is np.ndarray:
         return graph.toarray()
     return return_as(graph)
 
 
-@_deprecate_positional_args
 def img_to_graph(img, *, mask=None, return_as=sparse.coo_matrix, dtype=None):
-    """Graph of the pixel-to-pixel gradient connections
+    """Graph of the pixel-to-pixel gradient connections.
 
     Edges are weighted with the gradient values.
 
@@ -151,7 +158,12 @@ def img_to_graph(img, *, mask=None, return_as=sparse.coo_matrix, dtype=None):
         The class to use to build the returned adjacency matrix.
     dtype : dtype, default=None
         The data of the returned sparse matrix. By default it is the
-        dtype of img
+        dtype of img.
+
+    Returns
+    -------
+    graph : ndarray or a sparse matrix class
+        The computed adjacency matrix.
 
     Notes
     -----
@@ -167,21 +179,21 @@ def img_to_graph(img, *, mask=None, return_as=sparse.coo_matrix, dtype=None):
     return _to_graph(n_x, n_y, n_z, mask, img, return_as, dtype)
 
 
-@_deprecate_positional_args
-def grid_to_graph(n_x, n_y, n_z=1, *, mask=None, return_as=sparse.coo_matrix,
-                  dtype=int):
-    """Graph of the pixel-to-pixel connections
+def grid_to_graph(
+    n_x, n_y, n_z=1, *, mask=None, return_as=sparse.coo_matrix, dtype=int
+):
+    """Graph of the pixel-to-pixel connections.
 
     Edges exist if 2 voxels are connected.
 
     Parameters
     ----------
     n_x : int
-        Dimension in x axis
+        Dimension in x axis.
     n_y : int
-        Dimension in y axis
+        Dimension in y axis.
     n_z : int, default=1
-        Dimension in z axis
+        Dimension in z axis.
     mask : ndarray of shape (n_x, n_y, n_z), dtype=bool, default=None
         An optional mask of the image, to consider only part of the
         pixels.
@@ -189,7 +201,12 @@ def grid_to_graph(n_x, n_y, n_z=1, *, mask=None, return_as=sparse.coo_matrix,
             default=sparse.coo_matrix
         The class to use to build the returned adjacency matrix.
     dtype : dtype, default=int
-        The data of the returned sparse matrix. By default it is int
+        The data of the returned sparse matrix. By default it is int.
+
+    Returns
+    -------
+    graph : np.ndarray or a sparse matrix class
+        The computed adjacency matrix.
 
     Notes
     -----
@@ -200,13 +217,13 @@ def grid_to_graph(n_x, n_y, n_z=1, *, mask=None, return_as=sparse.coo_matrix,
     For compatibility, user code relying on this method should wrap its
     calls in ``np.asarray`` to avoid type issues.
     """
-    return _to_graph(n_x, n_y, n_z, mask=mask, return_as=return_as,
-                     dtype=dtype)
+    return _to_graph(n_x, n_y, n_z, mask=mask, return_as=return_as, dtype=dtype)
 
 
 ###############################################################################
 # From an image to a set of small image patches
 
+
 def _compute_n_patches(i_h, i_w, p_h, p_w, max_patches=None):
     """Compute the number of patches that will be extracted in an image.
 
@@ -232,14 +249,11 @@ def _compute_n_patches(i_h, i_w, p_h, p_w, max_patches=None):
     all_patches = n_h * n_w
 
     if max_patches:
-        if (isinstance(max_patches, (numbers.Integral))
-                and max_patches < all_patches):
+        if isinstance(max_patches, (numbers.Integral)) and max_patches < all_patches:
             return max_patches
-        elif (isinstance(max_patches, (numbers.Integral))
-              and max_patches >= all_patches):
+        elif isinstance(max_patches, (numbers.Integral)) and max_patches >= all_patches:
             return all_patches
-        elif (isinstance(max_patches, (numbers.Real))
-                and 0 < max_patches < 1):
+        elif isinstance(max_patches, (numbers.Real)) and 0 < max_patches < 1:
             return int(max_patches * all_patches)
         else:
             raise ValueError("Invalid value for max_patches: %r" % max_patches)
@@ -295,8 +309,9 @@ def _extract_patches(arr, patch_shape=8, extraction_step=1):
     slices = tuple(slice(None, None, st) for st in extraction_step)
     indexing_strides = arr[slices].strides
 
-    patch_indices_shape = ((np.array(arr.shape) - np.array(patch_shape)) //
-                           np.array(extraction_step)) + 1
+    patch_indices_shape = (
+        (np.array(arr.shape) - np.array(patch_shape)) // np.array(extraction_step)
+    ) + 1
 
     shape = tuple(list(patch_indices_shape) + list(patch_shape))
     strides = tuple(list(indexing_strides) + list(patch_strides))
@@ -305,10 +320,8 @@ def _extract_patches(arr, patch_shape=8, extraction_step=1):
     return patches
 
 
-@_deprecate_positional_args
-def extract_patches_2d(image, patch_size, *, max_patches=None,
-                       random_state=None):
-    """Reshape a 2D image into a collection of patches
+def extract_patches_2d(image, patch_size, *, max_patches=None, random_state=None):
+    """Reshape a 2D image into a collection of patches.
 
     The resulting patches are allocated in a dedicated array.
 
@@ -370,20 +383,22 @@ def extract_patches_2d(image, patch_size, *, max_patches=None,
     p_h, p_w = patch_size
 
     if p_h > i_h:
-        raise ValueError("Height of the patch should be less than the height"
-                         " of the image.")
+        raise ValueError(
+            "Height of the patch should be less than the height of the image."
+        )
 
     if p_w > i_w:
-        raise ValueError("Width of the patch should be less than the width"
-                         " of the image.")
+        raise ValueError(
+            "Width of the patch should be less than the width of the image."
+        )
 
     image = check_array(image, allow_nd=True)
     image = image.reshape((i_h, i_w, -1))
     n_colors = image.shape[-1]
 
-    extracted_patches = _extract_patches(image,
-                                         patch_shape=(p_h, p_w, n_colors),
-                                         extraction_step=1)
+    extracted_patches = _extract_patches(
+        image, patch_shape=(p_h, p_w, n_colors), extraction_step=1
+    )
 
     n_patches = _compute_n_patches(i_h, i_w, p_h, p_w, max_patches)
     if max_patches:
@@ -435,19 +450,18 @@ def reconstruct_from_patches_2d(patches, image_size):
     n_h = i_h - p_h + 1
     n_w = i_w - p_w + 1
     for p, (i, j) in zip(patches, product(range(n_h), range(n_w))):
-        img[i:i + p_h, j:j + p_w] += p
+        img[i : i + p_h, j : j + p_w] += p
 
     for i in range(i_h):
         for j in range(i_w):
             # divide by the amount of overlap
             # XXX: is this the most efficient way? memory-wise yes, cpu wise?
-            img[i, j] /= float(min(i + 1, p_h, i_h - i) *
-                               min(j + 1, p_w, i_w - j))
+            img[i, j] /= float(min(i + 1, p_h, i_h - i) * min(j + 1, p_w, i_w - j))
     return img
 
 
 class PatchExtractor(BaseEstimator):
-    """Extracts patches from a collection of images
+    """Extracts patches from a collection of images.
 
     Read more in the :ref:`User Guide <image_feature_extraction>`.
 
@@ -459,16 +473,20 @@ class PatchExtractor(BaseEstimator):
         The dimensions of one patch.
 
     max_patches : int or float, default=None
-        The maximum number of patches per image to extract. If max_patches is a
-        float in (0, 1), it is taken to mean a proportion of the total number
+        The maximum number of patches per image to extract. If `max_patches` is
+        a float in (0, 1), it is taken to mean a proportion of the total number
         of patches.
 
     random_state : int, RandomState instance, default=None
         Determines the random number generator used for random sampling when
-        `max_patches` is not None. Use an int to make the randomness
+        `max_patches is not None`. Use an int to make the randomness
         deterministic.
         See :term:`Glossary <random_state>`.
 
+    See Also
+    --------
+    reconstruct_from_patches_2d : Reconstruct image from all of its patches.
+
     Examples
     --------
     >>> from sklearn.datasets import load_sample_images
@@ -483,9 +501,8 @@ class PatchExtractor(BaseEstimator):
     >>> print('Patches shape: {}'.format(pe_trans.shape))
     Patches shape: (545706, 2, 2)
     """
-    @_deprecate_positional_args
-    def __init__(self, *, patch_size=None, max_patches=None,
-                 random_state=None):
+
+    def __init__(self, *, patch_size=None, max_patches=None, random_state=None):
         self.patch_size = patch_size
         self.max_patches = max_patches
         self.random_state = random_state
@@ -500,11 +517,19 @@ class PatchExtractor(BaseEstimator):
         ----------
         X : array-like of shape (n_samples, n_features)
             Training data.
+
+        y : Ignored
+            Not used, present for API consistency by convention.
+
+        Returns
+        -------
+        self : object
+            Returns the instance itself.
         """
         return self
 
     def transform(self, X):
-        """Transforms the image samples in X into a matrix of patch data.
+        """Transform the image samples in `X` into a matrix of patch data.
 
         Parameters
         ----------
@@ -541,10 +566,13 @@ class PatchExtractor(BaseEstimator):
         # extract the patches
         patches = np.empty(patches_shape)
         for ii, image in enumerate(X):
-            patches[ii * n_patches:(ii + 1) * n_patches] = extract_patches_2d(
-                image, patch_size, max_patches=self.max_patches,
-                random_state=self.random_state)
+            patches[ii * n_patches : (ii + 1) * n_patches] = extract_patches_2d(
+                image,
+                patch_size,
+                max_patches=self.max_patches,
+                random_state=self.random_state,
+            )
         return patches
 
     def _more_tags(self):
-        return {'X_types': ['3darray']}
+        return {"X_types": ["3darray"]}
